import React from 'react';
import { MapPanel, LayerPanel } from './components';
import GraphModel from './graphModel';
import { GraphType, Layer } from './types';
import { VISComponentType, VisualizationPropTypes } from '../../common';
import { GraphMetaData } from '@graphpolaris/shared/lib/data-access/statistics';

export type MapProps = {};

const configuration: MapProps = {};

export default function MapVis({ data }: VisualizationPropTypes) {
  const [layers, setLayers] = React.useState<Layer[]>([]);
  const [showFilter, setShowFilter] = React.useState<boolean>(false);

  let graph = React.useMemo(() => {
    try {
      const graphModel = new GraphModel();
      graphModel.consumeMessageFromBackend(data);
      return graphModel;
    } catch (e) {
      console.error(e);
      return null;
    }
  }, [data]);

  if (!graph) return <div>No data</div>;

  return (
    <div className="flex flex-row justify-between overflow-hidden h-full w-full font-sans">
      <MapPanel graph={graph} layers={layers} showFilter={showFilter} setShowFilter={setShowFilter} />
      {/* <LayerPanel layers={layers} setLayers={setLayers} graphInfo={graph.getGraphInfo()} setShowFilter={setShowFilter} /> */}
    </div>
  );
}

const MapSettings = ({
  configuration,
  graph,
  updateSettings,
}: {
  configuration: MapProps;
  graph: GraphMetaData;
  updateSettings: (val: any) => void;
}) => {
  return <div>To be implemented</div>;
};

export const MapComponent: VISComponentType = {
  displayName: 'MapVis',
  component: MapVis,
  settings: MapSettings,
  configuration: configuration,
};
